#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var commander_1 = __importDefault(require("commander"));
var index_1 = require("../index");
var parseLocale_1 = __importDefault(require("../util/parseLocale"));
var program = new commander_1.default.Command();
program
    .name('arb2po')
    .option('--sourcefile <filename>', 'source ARB file (required)')
    .option('--targetfile <filename>', 'target ARB file')
    .option('--original <value>', 'where the translations come from')
    .option('--sourcelang <locale>', 'source locale override, e.g. en-US, in case it cannot be determined from file content or file name')
    .option('--targetlang <locale>', 'target locale override, e.g. de-DE, in case it cannot be determined from file content or file name')
    .option('--out <filename>', 'write PO to file if given or stdout if omitted')
    .parse(process.argv);
// No params
if (program.rawArgs.length <= 2) {
    program.help(); // shows help and exits
}
try {
    if (!program.sourcefile) {
        throw new Error("option '--sourcefile <filename>' is required");
    }
    var sourceContent = fs_1.default.readFileSync(program.sourcefile, 'utf8');
    var targetContent = program.targetfile && fs_1.default.readFileSync(program.targetfile, 'utf8');
    var result = index_1.convertFromArb('gettext', {
        source: sourceContent,
        target: targetContent,
        original: program.original,
        sourceLanguage: parseLocale_1.default(program.sourcelang, determineArbLocale(sourceContent), program.sourcefile),
        targetLanguage: program.targetfile && parseLocale_1.default(program.targetlang, determineArbLocale(targetContent), program.targetfile),
    });
    if (program.out) {
        fs_1.default.writeFileSync(program.out, result.content);
    }
    else {
        process.stdout.write(result.content);
    }
}
catch (error) {
    console.log("error: " + error.message);
    process.exit(1);
}
function determineArbLocale(content) {
    var matches = content.match(/"@@locale":\s*"(.+)"/);
    if (matches) {
        return matches[1];
    }
    return '';
}
