#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var commander_1 = __importDefault(require("commander"));
var index_1 = require("../index");
var program = new commander_1.default.Command();
program
    .name('xliff2arb')
    .option('--file <filename>', 'source XLIFF file (required)')
    .option('--sourceout <filename>', 'write source ARB to file if given or stdout if omitted')
    .option('--targetout <filename>', 'write target ARB to file if given')
    .parse(process.argv);
// No params
if (program.rawArgs.length <= 2) {
    program.help(); // shows help and exits
}
try {
    if (!program.file) {
        throw new Error("option '--file <filename>' is required");
    }
    var fileContent = fs_1.default.readFileSync(program.file, 'utf8');
    var result = index_1.parseToArb('xliff', {
        content: fileContent,
    });
    if (program.sourceout) {
        fs_1.default.writeFileSync(program.sourceout, result.source);
    }
    else {
        process.stdout.write(result.source);
    }
    if (program.targetout) {
        fs_1.default.writeFileSync(program.targetout, result.target);
    }
}
catch (error) {
    console.log("error: " + error.message);
    console.log(error);
    process.exit(1);
}
