"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var gettext_1 = require("./gettext");
describe('convert ARB to gettext PO', function () {
    var source = JSON.stringify({
        "@@locale": "en_US",
        "@@last_modified": "2019-12-31T10:00:00.000000",
        "simple": "Super simple",
        "@simple": {
            "description": "A simple string",
            "type": "text",
            "placeholders": {}
        },
        "param": "Walk {distance}",
        "@param": {
            "type": "text",
            "placeholders": {
                "distance": {
                    "example": "500 m"
                },
            }
        },
        "long": "Very long string that exceeds the max char limit of 80 characters easily and thus forces a line break in the resulting PO file",
        "@long": {
            "description": "We need to test long comments as well, so this is me wasting time by writing something meaningful. Did you really read this to the end?",
            "type": "text",
            "placeholders": {},
        },
    });
    var target = JSON.stringify({
        "@@locale": "de_DE",
        "@@last_modified": "2019-12-31T10:00:00.000000",
        "simple": "Super simpel",
        "@simple": {
            "description": "A simple string",
            "type": "text",
            "placeholders": {}
        },
        "param": "Laufe {distance}",
        "@param": {
            "type": "text",
            "placeholders": {
                "distance": {
                    "example": "500 m"
                },
            }
        },
        "long": "Ein sehr langer String der problemlos das maximale Zeichenlimit von 80 Zeichen überschreitet und damit einen Zeilenumbruch in der resultierenden PO-Datei erwingt",
        "@long": {
            "description": "We need to test long comments as well, so this is me wasting time by writing something meaningful. Did you really read this to the end?",
            "type": "text",
            "placeholders": {},
        },
    });
    test('with empty source and no other options', function () {
        var expectedContent = ''
            + '# Translation converted from ARB\n'
            + '# original: \n'
            + '# srcLang: \n'
            + '# trgLang: \n'
            + 'msgid ""\n'
            + 'msgstr ""\n'
            + '"PO-Revision-Date: ' + gettext_1.formatDate(new Date()) + '"\n'
            + '"MIME-Version: 1.0"\n'
            + '"Content-Type: text/plain; charset=UTF-8"\n'
            + '"Content-Transfer-Encoding: 8bit"\n';
        expect(gettext_1.convert({ source: '{}' })).toEqual({
            content: expectedContent,
        });
    });
    test('with source strings only', function () {
        var expectedContent = ''
            + '# Translation converted from ARB\n'
            + '# original: some ns\n'
            + '# srcLang: en-US\n'
            + '# trgLang: \n'
            + 'msgid ""\n'
            + 'msgstr ""\n'
            + '"PO-Revision-Date: ' + gettext_1.formatDate(new Date()) + '"\n'
            + '"MIME-Version: 1.0"\n'
            + '"Content-Type: text/plain; charset=UTF-8"\n'
            + '"Content-Transfer-Encoding: 8bit"\n'
            + '\n'
            + '#. A simple string\n'
            + 'msgctxt "simple"\n'
            + 'msgid "Super simple"\n'
            + 'msgstr ""\n'
            + '\n'
            + '#. {distance} example: 500 m\n'
            + 'msgctxt "param"\n'
            + 'msgid "Walk {distance}"\n'
            + 'msgstr ""\n'
            + '\n'
            + '#. We need to test long comments as well, so this is me wasting time by writing \n'
            + '#. something meaningful. Did you really read this to the end?\n'
            + 'msgctxt "long"\n'
            + 'msgid ""\n'
            + '"Very long string that exceeds the max char limit of 80 characters easily and t"\n'
            + '"hus forces a line break in the resulting PO file"\n'
            + 'msgstr ""\n';
        expect(gettext_1.convert({
            source: source,
            sourceLanguage: 'en-US',
            original: 'some ns'
        })).toEqual({
            content: expectedContent,
        });
    });
    test('with source and target strings', function () {
        var expectedContent = ''
            + '# Translation converted from ARB\n'
            + '# original: some ns\n'
            + '# srcLang: en-US\n'
            + '# trgLang: de-DE\n'
            + 'msgid ""\n'
            + 'msgstr ""\n'
            + '"PO-Revision-Date: ' + gettext_1.formatDate(new Date()) + '"\n'
            + '"MIME-Version: 1.0"\n'
            + '"Content-Type: text/plain; charset=UTF-8"\n'
            + '"Content-Transfer-Encoding: 8bit"\n'
            + '\n'
            + '#. A simple string\n'
            + 'msgctxt "simple"\n'
            + 'msgid "Super simple"\n'
            + 'msgstr "Super simpel"\n'
            + '\n'
            + '#. {distance} example: 500 m\n'
            + 'msgctxt "param"\n'
            + 'msgid "Walk {distance}"\n'
            + 'msgstr "Laufe {distance}"\n'
            + '\n'
            + '#. We need to test long comments as well, so this is me wasting time by writing \n'
            + '#. something meaningful. Did you really read this to the end?\n'
            + 'msgctxt "long"\n'
            + 'msgid ""\n'
            + '"Very long string that exceeds the max char limit of 80 characters easily and t"\n'
            + '"hus forces a line break in the resulting PO file"\n'
            + 'msgstr ""\n'
            + '"Ein sehr langer String der problemlos das maximale Zeichenlimit von 80 Zeichen"\n'
            + '" überschreitet und damit einen Zeilenumbruch in der resultierenden PO-Datei er"\n'
            + '"wingt"\n';
        expect(gettext_1.convert({
            source: source,
            target: target,
            sourceLanguage: 'en-US',
            targetLanguage: 'de-DE',
            original: 'some ns'
        })).toEqual({
            content: expectedContent,
        });
    });
});
describe('gettext utility functions', function () {
});
